@@ -264,6 +264,12 @@ func GetLicense(http *helper.HTTP, resetURI string) (*License, error) {
 	// First, check the cache
 	license := licenseCache.get()
 
+	// License found in cache, return it
+	if license != nil {
+		return license, nil
+	}
+
+	// License not found in cache, fetch it from Elasticsearch
 	info, err := GetInfo(http, resetURI)
 	if err != nil {
 		return nil, err
@@ -275,24 +281,22 @@ func GetLicense(http *helper.HTTP, resetURI string) (*License, error) {
 		licensePath = "_license"
 	}
 
-	// Not cached, fetch license from Elasticsearch
-	if license == nil {
-		content, err := fetchPath(http, resetURI, licensePath, "")
-		if err != nil {
-			return nil, err
-		}
-
-		var data licenseWrapper
-		err = json.Unmarshal(content, &data)
-		if err != nil {
-			return nil, err
-		}
-
-		// Cache license for a minute
-		licenseCache.set(&data.License, time.Minute)
+	content, err := fetchPath(http, resetURI, licensePath, "")
+	if err != nil {
+		return nil, err
 	}
 
-	return licenseCache.get(), nil
+	var data licenseWrapper
+	err = json.Unmarshal(content, &data)
+	if err != nil {
+		return nil, err
+	}
+
+	// Cache license for a minute
+	license = &data.License
+	licenseCache.set(license, time.Minute)
+
+	return license, nil
 }
 
 // GetClusterState returns cluster state information.
@@ -354,6 +358,27 @@ func GetStackUsage(http *helper.HTTP, resetURI string) (common.MapStr, error) {
 	return stackUsage, err
 }
 
+// IsMLockAllEnabled returns if the given Elasticsearch node has mlockall enabled
+func IsMLockAllEnabled(http *helper.HTTP, resetURI, nodeID string) (bool, error) {
+	content, err := fetchPath(http, resetURI, "_nodes/"+nodeID, "filter_path=nodes.*.process.mlockall")
+	if err != nil {
+		return false, err
+	}
+
+	var response map[string]map[string]map[string]map[string]bool
+	err = json.Unmarshal(content, &response)
+	if err != nil {
+		return false, err
+	}
+
+	for _, nodeInfo := range response["nodes"] {
+		mlockall := nodeInfo["process"]["mlockall"]
+		return mlockall, nil
+	}
+
+	return false, fmt.Errorf("could not determine if mlockall is enabled on node ID = %v", nodeID)
+}
+
 // PassThruField copies the field at the given path from the given source data object into
 // the same path in the given target data object.
 func PassThruField(fieldPath string, sourceData, targetData common.MapStr) error {
